.. _pydl.goddard.misc:

==========================================
Goddard misc package (`pydl.goddard.misc`)
==========================================

Introduction
------------

This is a placeholder for Goddard misc package documentation.

.. automodapi:: pydl.goddard.misc
   :no-inheritance-diagram:
